#include <random>
#include <iostream>
#include <fstream>
#include <ctime>
#include <unordered_map>

const int MAX_LINES = 500000;

const int BUFF_SIZE = 2048;

struct randomGenerator {

    static int get() {
        static std::mt19937 gen(std::time(0));

        int x = gen();

        if (x < 0)
            x = -x;

        return x;
    }
};

template<class key_type>
struct node {
    node * L, * R;
    int priority;
    key_type key;
    int under;

    node() {
        L = R = 0;
        priority = key = 0;
        under = 0;
    }

    void init(const key_type & key) {
        L = R = 0;
        this->priority = randomGenerator::get();
        this->key = key;
        this->under = 1;
    }

    node(const key_type & key) {
        this->init(key);
    }
};

node<long long> * newNode(const long long key = -1) {
    static node<long long>* buffer = new node<long long>[BUFF_SIZE];
    static int at = 0;
    if(at == BUFF_SIZE) {
        buffer = new node<long long>[BUFF_SIZE];
        at = 0;
    }

    if(key == -1) {
        return &buffer[at++];
    } else {
        buffer[at].init(key);
        return &buffer[at++];
    }
}

template<class key_type>
struct Treap {
    node<key_type> * root;

    Treap() {
        root = 0;
    }

    int under(node<key_type> * & now) {
        if(now == 0)
            return 0;
        else return now->under;
    }

    void merge(node<key_type> * & now) {
        if(now == 0)
            return;
        now->under = 1 + under(now->L) + under(now->R);
    }

    void rotRight(node<key_type> * & now) {
        node<key_type> *const L = now->L;
        now->L = L->R;
        L->R = now;
        now = L;
    }

    void rotLeft(node<key_type> * & now) {
        node<key_type> *const R = now->R;
        now->R = R->L;
        R->L = now;
        now = R;
    }

    void balance(node<key_type> * & now) {
       if(now->L != 0 && now->L->priority > now->priority) {
           rotRight(now);
       } else if(now->R != 0 && now->R->priority > now->priority) {
           rotLeft(now);
       }

       merge(now);
       merge(now->L);
       merge(now->R);
    }


    void insert(node<key_type> * &now, const key_type & key) {
        if(now == 0) {
            now = newNode(key);
        } else {
            if(key <= now->key)
                insert(now->L, key);
            else
                insert(now->R, key);
            balance(now);
        }
    }

    void insert(const key_type & key) {
        insert(root, key);
    }

    int before(node<key_type> * & now, const key_type & key, const int sum) {
        if(now == 0)
            return sum;

        if(now->key <= key)
            return before(now->R, key, sum + 1 + under(now->L));
        else
            return before(now->L, key, sum);
    }

    int before(const key_type & key) {
        return before(root, key, 0);
    }

    void debug(node<key_type> * now) const {
        if(now) {
            debug(now->L);
            debug(now->R);
            std::cerr << now->key << "\n";
        }
    }


    void debug() {
        debug(root);
    }

};

struct line {
    Treap<long long> plus, minus;

    void update(const long long x, const long long y) {
        plus.insert(x);
        minus.insert(y + 1);
    }

    int query(const long long x) {
        return plus.before(x) - minus.before(x);
    }
};

line L[MAX_LINES];

std::unordered_map<long long, int> H;

int getMap(const long long &x) {
    if(H.count(x))
        return H[x];
    else
        return H[x] = H.size();
}

void initialize(long long n,long long m) {
    //do nothing!
}

void update(long long x, long long y1, long long y2) {
    int lineNumber = getMap(x);
    L[lineNumber].update(y1, y2);
}

int query(long long x, long long y) {
    int lineNumber = getMap(x);
    return L[lineNumber].query(y);
}
