#include <fstream>
#include <unordered_map>

const int MAX_LINES = 500000;
const int BUFF_SIZE = 2048;

struct node {
    int sum;
    node * L, * R;

    node():
        sum(0),
        L(0),
        R(0){}

};

node* newNode() {
    static node* buffer = new node[BUFF_SIZE];
    static int at = 0;
    if(at == BUFF_SIZE) {
        buffer = new node[BUFF_SIZE];
        at = 0;
    }
    return &buffer[at++];
}

long long n, m;

struct AINT {
    node * root;

    AINT() {
        root = 0;
    }

    void update(node *& now, const long long x, const long long y, const long long lo, const long long hi) {
        if(!now)
            now = newNode();
        if(x <= lo && hi <= y) {
            now->sum++;
            return;
        }
        const long long mid = lo + (hi - lo) / 2;
        if(x <= mid)
            update(now->L, x, y, lo, mid);
        if(mid + 1 <= y)
            update(now->R, x, y, mid + 1, hi);
    }

    void update(const long long x, const long long y) {
        return update(root, x, y, 1, m);
    }

    int query(node *& now, const long long x, const long long lo, const long long hi, const int total) {
        if(!now)
            return total;

        const long long mid = lo + (hi - lo) / 2;

        if(x <= mid)
            return query(now->L, x, lo, mid, total + now->sum);
        else
            return query(now->R, x, mid + 1, hi, total + now->sum);

    }

    int query(const long long x) {
        return query(root, x, 1, m, 0);
    }

};

struct line {
    AINT t;
    void update(const long long x, const long long y) {
        t.update(x, y);
    }
    int query(const long long x) {
        return t.query(x);
    }
} L[MAX_LINES];

std::unordered_map<long long, int> H;

int getMap(const long long &x) {
    if(H.count(x))
        return H[x];
    else
        return H[x] = H.size();
}

void initialize(long long nn, long long mm) {
    n = nn;
    m = mm;
}


void update(long long x, long long y1, long long y2) {
    int lineNumber = getMap(x);
    L[lineNumber].update(y1, y2);
}

int query(long long x, long long y) {
    int lineNumber = getMap(x);
    return L[lineNumber].query(y);
}
